@@ -6,6 +6,7 @@ use regex::Regex;
 use serde::Serialize;
 use serde::{de, Deserialize};
 use std::num::ParseIntError;
+use std::ops::Mul;
 
 pub type ColorWGPU = wgpu::Color;
 pub type ColorArray = [f32; 4];
@@ -18,6 +19,32 @@ pub struct ColorRgb {
     pub b: u8,
 }
 
+impl Mul<f32> for ColorRgb {
+    type Output = ColorRgb;
+
+    fn mul(self, rhs: f32) -> ColorRgb {
+        let result = ColorRgb {
+            r: (f32::from(self.r) * rhs).clamp(0.0, 255.0) as u8,
+            g: (f32::from(self.g) * rhs).clamp(0.0, 255.0) as u8,
+            b: (f32::from(self.b) * rhs).clamp(0.0, 255.0) as u8,
+        };
+
+        tracing::trace!(
+            "Scaling ColorRgb by {} from {:?} to {:?}",
+            rhs,
+            self,
+            result
+        );
+        result
+    }
+}
+
+impl From<&ColorRgb> for ColorArray {
+    fn from(color: &ColorRgb) -> ColorArray {
+        color.to_arr()
+    }
+}
+
 impl ColorRgb {
     pub fn from_color_arr(arr: ColorArray) -> ColorRgb {
         ColorRgb {
@@ -121,113 +148,113 @@ pub struct Colors {
     #[serde(default = "defaults::white", deserialize_with = "deserialize_to_arr")]
     pub white: ColorArray,
     #[serde(
-        default = "defaults::dim_black",
-        deserialize_with = "deserialize_to_arr",
+        default = "Option::default",
+        deserialize_with = "deserialize_to_arr_opt",
         rename = "dim-black"
     )]
-    pub dim_black: ColorArray,
+    pub dim_black: Option<ColorArray>,
     #[serde(
-        default = "defaults::dim_blue",
-        deserialize_with = "deserialize_to_arr",
+        default = "Option::default",
+        deserialize_with = "deserialize_to_arr_opt",
         rename = "dim-blue"
     )]
-    pub dim_blue: ColorArray,
+    pub dim_blue: Option<ColorArray>,
     #[serde(
-        default = "defaults::dim_cyan",
-        deserialize_with = "deserialize_to_arr",
+        default = "Option::default",
+        deserialize_with = "deserialize_to_arr_opt",
         rename = "dim-cyan"
     )]
-    pub dim_cyan: ColorArray,
+    pub dim_cyan: Option<ColorArray>,
     #[serde(
-        default = "defaults::dim_foreground",
-        deserialize_with = "deserialize_to_arr",
+        default = "Option::default",
+        deserialize_with = "deserialize_to_arr_opt",
         rename = "dim-foreground"
     )]
-    pub dim_foreground: ColorArray,
+    pub dim_foreground: Option<ColorArray>,
     #[serde(
-        default = "defaults::dim_green",
-        deserialize_with = "deserialize_to_arr",
+        default = "Option::default",
+        deserialize_with = "deserialize_to_arr_opt",
         rename = "dim-green"
     )]
-    pub dim_green: ColorArray,
+    pub dim_green: Option<ColorArray>,
     #[serde(
-        default = "defaults::dim_magenta",
-        deserialize_with = "deserialize_to_arr",
+        default = "Option::default",
+        deserialize_with = "deserialize_to_arr_opt",
         rename = "dim-magenta"
     )]
-    pub dim_magenta: ColorArray,
+    pub dim_magenta: Option<ColorArray>,
     #[serde(
-        default = "defaults::dim_red",
-        deserialize_with = "deserialize_to_arr",
+        default = "Option::default",
+        deserialize_with = "deserialize_to_arr_opt",
         rename = "dim-red"
     )]
-    pub dim_red: ColorArray,
+    pub dim_red: Option<ColorArray>,
     #[serde(
-        default = "defaults::dim_white",
-        deserialize_with = "deserialize_to_arr",
+        default = "Option::default",
+        deserialize_with = "deserialize_to_arr_opt",
         rename = "dim-white"
     )]
-    pub dim_white: ColorArray,
+    pub dim_white: Option<ColorArray>,
     #[serde(
-        default = "defaults::dim_yellow",
-        deserialize_with = "deserialize_to_arr",
+        default = "Option::default",
+        deserialize_with = "deserialize_to_arr_opt",
         rename = "dim-yellow"
     )]
-    pub dim_yellow: ColorArray,
+    pub dim_yellow: Option<ColorArray>,
     #[serde(
-        default = "defaults::light_black",
-        deserialize_with = "deserialize_to_arr",
+        default = "Option::default",
+        deserialize_with = "deserialize_to_arr_opt",
         rename = "light-black"
     )]
-    pub light_black: ColorArray,
+    pub light_black: Option<ColorArray>,
     #[serde(
-        default = "defaults::light_blue",
-        deserialize_with = "deserialize_to_arr",
+        default = "Option::default",
+        deserialize_with = "deserialize_to_arr_opt",
         rename = "light-blue"
     )]
-    pub light_blue: ColorArray,
+    pub light_blue: Option<ColorArray>,
     #[serde(
-        default = "defaults::light_cyan",
-        deserialize_with = "deserialize_to_arr",
+        default = "Option::default",
+        deserialize_with = "deserialize_to_arr_opt",
         rename = "light-cyan"
     )]
-    pub light_cyan: ColorArray,
+    pub light_cyan: Option<ColorArray>,
     #[serde(
-        default = "defaults::light_foreground",
-        deserialize_with = "deserialize_to_arr",
+        default = "Option::default",
+        deserialize_with = "deserialize_to_arr_opt",
         rename = "light-foreground"
     )]
-    pub light_foreground: ColorArray,
+    pub light_foreground: Option<ColorArray>,
     #[serde(
-        default = "defaults::light_green",
-        deserialize_with = "deserialize_to_arr",
+        default = "Option::default",
+        deserialize_with = "deserialize_to_arr_opt",
         rename = "light-green"
     )]
-    pub light_green: ColorArray,
+    pub light_green: Option<ColorArray>,
     #[serde(
-        default = "defaults::light_magenta",
-        deserialize_with = "deserialize_to_arr",
+        default = "Option::default",
+        deserialize_with = "deserialize_to_arr_opt",
         rename = "light-magenta"
     )]
-    pub light_magenta: ColorArray,
+    pub light_magenta: Option<ColorArray>,
     #[serde(
-        default = "defaults::light_red",
-        deserialize_with = "deserialize_to_arr",
+        default = "Option::default",
+        deserialize_with = "deserialize_to_arr_opt",
         rename = "light-red"
     )]
-    pub light_red: ColorArray,
+    pub light_red: Option<ColorArray>,
     #[serde(
-        default = "defaults::light_white",
-        deserialize_with = "deserialize_to_arr",
+        default = "Option::default",
+        deserialize_with = "deserialize_to_arr_opt",
         rename = "light-white"
     )]
-    pub light_white: ColorArray,
+    pub light_white: Option<ColorArray>,
     #[serde(
-        default = "defaults::light_yellow",
-        deserialize_with = "deserialize_to_arr",
+        default = "Option::default",
+        deserialize_with = "deserialize_to_arr_opt",
         rename = "light-yellow"
     )]
-    pub light_yellow: ColorArray,
+    pub light_yellow: Option<ColorArray>,
     #[serde(
         default = "defaults::selection_background",
         deserialize_with = "deserialize_to_arr",
@@ -240,7 +267,7 @@ pub struct Colors {
         rename = "selection-foreground"
     )]
     pub selection_foreground: ColorArray,
-    #[serde(default = "defaults::cursor", deserialize_with = "deserialize_to_arr")]
+    #[serde(default = "defaults::split", deserialize_with = "deserialize_to_arr")]
     pub split: ColorArray,
     #[serde(
         default = "defaults::search_match_background",
@@ -284,30 +311,30 @@ impl Default for Colors {
             tabs_active_foreground: defaults::tabs_active_foreground(),
             tabs_foreground: defaults::tabs_foreground(),
             cursor: defaults::cursor(),
-            split: defaults::cursor(),
+            split: defaults::split(),
             vi_cursor: defaults::vi_cursor(),
             black: defaults::black(),
             cyan: defaults::cyan(),
             magenta: defaults::magenta(),
             white: defaults::white(),
-            dim_black: defaults::dim_black(),
-            dim_blue: defaults::dim_blue(),
-            dim_cyan: defaults::dim_cyan(),
-            dim_foreground: defaults::dim_foreground(),
-            dim_green: defaults::dim_green(),
-            dim_magenta: defaults::dim_magenta(),
-            dim_red: defaults::dim_red(),
-            dim_white: defaults::dim_white(),
-            dim_yellow: defaults::dim_yellow(),
-            light_black: defaults::light_black(),
-            light_blue: defaults::light_blue(),
-            light_cyan: defaults::light_cyan(),
-            light_foreground: defaults::light_foreground(),
-            light_green: defaults::light_green(),
-            light_magenta: defaults::light_magenta(),
-            light_red: defaults::light_red(),
-            light_white: defaults::light_white(),
-            light_yellow: defaults::light_yellow(),
+            dim_black: None,
+            dim_blue: None,
+            dim_cyan: None,
+            dim_foreground: None,
+            dim_green: None,
+            dim_magenta: None,
+            dim_red: None,
+            dim_white: None,
+            dim_yellow: None,
+            light_black: None,
+            light_blue: None,
+            light_cyan: None,
+            light_foreground: None,
+            light_green: None,
+            light_magenta: None,
+            light_red: None,
+            light_white: None,
+            light_yellow: None,
             selection_background: defaults::selection_background(),
             selection_foreground: defaults::selection_foreground(),
             search_match_background: defaults::search_match_background(),
@@ -479,13 +506,10 @@ impl ColorBuilder {
 
     pub fn from_hex(mut hex: String, conversion_type: Format) -> Result<Self, String> {
         let mut alpha: f64 = 1.0;
-        let _match3or4_hex = "#?[a-f\\d]{3}[a-f\\d]?";
-        let _match6or8_hex = "#?[a-f\\d]{6}([a-f\\d]{2})?";
-        let non_hex_chars = Regex::new(r"(?i)[^#a-f\\0-9]").unwrap();
+        let non_hex_chars = Regex::new(r"(?i)[^#a-f\d]").unwrap();
 
-        // ^#?[a-f\\d]{3}[a-f\\d]?$|^#?[a-f\\d]{6}([a-f\\d]{2})?$ , "i"
-        let valid_hex_size =
-            Regex::new(r"(?i)^#?[a-f\\0-9]{6}([a-f]\\0-9]{2})?$").unwrap();
+        // match valid 6 or 8 hex characters
+        let valid_hex_size = Regex::new(r"(?i)^#?[a-f\d]{6}([a-f\d]{2})?$").unwrap();
 
         if non_hex_chars.is_match(&hex) {
             return Err(String::from("Error: Character is not valid"));
@@ -498,16 +522,14 @@ impl ColorBuilder {
         hex = hex.replace('#', "");
 
         if hex.len() == 8 {
-            // split_at(6, 8)
-            let items = hex.split_at(4);
-            let alpha_from_hex = items.1.to_string().parse::<i32>().unwrap();
-            hex = items.0.to_string();
-            alpha = (alpha_from_hex / 255) as f64;
-            // hex = hex.split_at(1).0.to_string();
+            let (rgb_part, alpha_part) = hex.split_at(6);
+            let alpha_from_hex = i32::from_str_radix(alpha_part, 16).unwrap();
+            hex = rgb_part.to_string();
+            alpha = (alpha_from_hex as f64) / 255.0;
         }
 
         let rgb = decode_hex(&hex).unwrap_or_default();
-        if rgb.is_empty() || rgb.len() > 4 {
+        if rgb.is_empty() || (rgb.len() != 3 && rgb.len() != 4) {
             return Err(String::from("Error: Invalid string, not able to convert"));
         }
 
@@ -638,6 +660,19 @@ where
     }
 }
 
+pub fn deserialize_to_arr_opt<'de, D>(
+    deserializer: D,
+) -> Result<Option<ColorArray>, D::Error>
+where
+    D: de::Deserializer<'de>,
+{
+    let s = String::deserialize(deserializer)?;
+    match ColorBuilder::from_hex(s, Format::SRGB0_1) {
+        Ok(color) => Ok(Some(color.to_arr())),
+        Err(e) => Err(serde::de::Error::custom(e)),
+    }
+}
+
 #[cfg(test)]
 mod tests {
     use super::*;
@@ -738,4 +773,58 @@ mod tests {
             }
         );
     }
+
+    #[test]
+    fn test_conversion_from_gray_hex_with_alpha() {
+        let color_with_alpha =
+            ColorBuilder::from_hex(String::from("#15151580"), Format::SRGB0_255).unwrap();
+        assert_eq!(
+            color_with_alpha,
+            ColorBuilder {
+                red: 21.0,
+                green: 21.0,
+                blue: 21.0,
+                alpha: 128.0 / 255.0
+            }
+        );
+
+        let color_with_alpha_srgb0_1 =
+            ColorBuilder::from_hex(String::from("#15151580"), Format::SRGB0_1).unwrap();
+        assert_eq!(
+            color_with_alpha_srgb0_1,
+            ColorBuilder {
+                red: 21.0 / 255.0,
+                green: 21.0 / 255.0,
+                blue: 21.0 / 255.0,
+                alpha: 128.0 / 255.0
+            }
+        );
+    }
+
+    #[test]
+    fn test_conversion_from_teal_hex_with_alpha() {
+        let color_with_alpha =
+            ColorBuilder::from_hex(String::from("#06a49b99"), Format::SRGB0_255).unwrap();
+        assert_eq!(
+            color_with_alpha,
+            ColorBuilder {
+                red: 6.0,
+                green: 164.0,
+                blue: 155.0,
+                alpha: 153.0 / 255.0
+            }
+        );
+
+        let color_with_alpha_srgb0_1 =
+            ColorBuilder::from_hex(String::from("#06a49b99"), Format::SRGB0_1).unwrap();
+        assert_eq!(
+            color_with_alpha_srgb0_1,
+            ColorBuilder {
+                red: 6.0 / 255.0,
+                green: 164.0 / 255.0,
+                blue: 155.0 / 255.0,
+                alpha: 153.0 / 255.0
+            }
+        );
+    }
 }
